@@ -6,9 +6,11 @@ use strict;
 use warnings;
 use routines;
 
+use Sub::Util ();
+
 use parent 'Data::Object::Name';
 
-our $VERSION = '2.05'; # VERSION
+our $VERSION = '2.06'; # VERSION
 
 # METHODS
 
@@ -44,6 +46,11 @@ method arrays() {
   return $arrays;
 }
 
+method authority() {
+
+  return $self->scalar('AUTHORITY');
+}
+
 method base() {
 
   return $self->parse->[-1];
@@ -67,17 +74,21 @@ method call($func, @args) {
   unless ($func) {
     require Carp;
 
-    my $text = qq[Attempt to call undefined object method in package "$class"];
+    my $text = qq[Attempt to call undefined class method in package "$class"];
 
     Carp::confess $text;
   }
 
   my $next = $class->can($func);
 
+  unless ($next) {
+    $next = sub { $class->$func(@args) } if $class->can('AUTOLOAD');
+  }
+
   unless ($next) {
     require Carp;
 
-    my $text = qq[Unable to locate object method "$func" via package "$class"];
+    my $text = qq[Unable to locate class method "$func" via package "$class"];
 
     Carp::confess $text;
   }
@@ -218,6 +229,30 @@ method id() {
   return $self->label;
 }
 
+method init() {
+  my $class = $self->package;
+
+  if ($self->routine('import')) {
+
+    return $self->package;
+  }
+
+  $class = $self->locate ? $self->load : $self->package;
+
+  if ($self->routine('import')) {
+
+    return $class;
+  }
+  else {
+
+    my $import = sub { $class };
+
+    $self->inject('import', $import);
+
+    return $class;
+  }
+}
+
 method inherits() {
 
   return $self->array('ISA');
@@ -228,6 +263,17 @@ method included() {
   return $INC{$self->format('path', '%s.pm')};
 }
 
+method inject($name, $coderef) {
+  no strict 'refs';
+  no warnings 'redefine';
+
+  my $class = $self->package;
+
+  return *{"${class}::${name}"} = Sub::Util::set_subname(
+    "${class}::${name}", $coderef || sub{$class}
+  );
+}
+
 method load() {
   my $class = $self->package;
 
@@ -462,7 +508,7 @@ method version() {
 
 =head1 NAME
 
-Data::Object::Space
+Data::Object::Space - Namespace Class
 
 =cut
 
@@ -599,6 +645,53 @@ names.
 
 =cut
 
+=head2 authority
+
+  authority() : Maybe[Str]
+
+The authority method returns the C<AUTHORITY> declared on the target package,
+if any.
+
+=over 4
+
+=item authority example #1
+
+  package Foo::Boo;
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo/boo');
+
+  $space->authority
+
+  # undef
+
+=back
+
+=over 4
+
+=item authority example #2
+
+  package Foo::Boo;
+
+  our $AUTHORITY = 'cpan:AWNCORP';
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('foo/boo');
+
+  $space->authority
+
+  # 'cpan:AWNCORP'
+
+=back
+
+=cut
+
 =head2 base
 
   base() : Str
@@ -749,6 +842,36 @@ and if successful returns the resulting value.
 
 =back
 
+=over 4
+
+=item call example #2
+
+  # given: synopsis
+
+  package Zoo;
+
+  sub import;
+
+  sub AUTOLOAD {
+    bless {};
+  }
+
+  sub DESTROY {
+    ; # noop
+  }
+
+  package main;
+
+  use Data::Object::Space;
+
+  $space = Data::Object::Space->new('zoo');
+
+  $space->call('start')
+
+  # bless({}, 'Zoo')
+
+=back
+
 =cut
 
 =head2 child
@@ -1069,6 +1192,57 @@ derived from.
 
 =cut
 
+=head2 init
+
+  init() : Str
+
+The init method ensures that the package namespace is loaded and, whether
+created in-memory or on-disk, is flagged as being loaded and loadable.
+
+=over 4
+
+=item init example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('kit');
+
+  $space->init
+
+  # Kit
+
+=back
+
+=cut
+
+=head2 inject
+
+  inject(Str $name, Maybe[CodeRef] $coderef) : Any
+
+The inject method monkey-patches the package namespace, installing a named
+subroutine into the package which can then be called normally, returning the
+fully-qualified subroutine name.
+
+=over 4
+
+=item inject example #1
+
+  package main;
+
+  use Data::Object::Space;
+
+  my $space = Data::Object::Space->new('kit');
+
+  $space->inject('build', sub { 'finished' });
+
+  # *Kit::build
+
+=back
+
+=cut
+
 =head2 load
 
   load() : Str
